==> eam-wshub-proxyclient-11.4-12-sources.jar: net/datastream/schemas/mp_fields/WOSCHEDULEID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOSCHEDULECODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "activityid",
    "woschedulecode"
})
@XmlRootElement(name = "WOSCHEDULEID")
public class WOSCHEDULEID {

    @XmlElement(name = "ACTIVITYID", required = true)
    protected ACTIVITYID activityid;
    @XmlElement(name = "WOSCHEDULECODE", required = true)
    protected String woschedulecode;

    /**
     * Obtient la valeur de la propriété activityid.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Définit la valeur de la propriété activityid.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Obtient la valeur de la propriété woschedulecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWOSCHEDULECODE() {
        return woschedulecode;
    }

    /**
     * Définit la valeur de la propriété woschedulecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWOSCHEDULECODE(String value) {
        this.woschedulecode = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/WOSCHEDULEID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOSCHEDULECODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "activityid",
    "woschedulecode"
})
@XmlRootElement(name = "WOSCHEDULEID")
public class WOSCHEDULEID {

    @XmlElement(name = "ACTIVITYID", required = true)
    protected ACTIVITYID activityid;
    @XmlElement(name = "WOSCHEDULECODE", required = true)
    protected String woschedulecode;

    /**
     * Gets the value of the activityid property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Sets the value of the activityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Gets the value of the woschedulecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWOSCHEDULECODE() {
        return woschedulecode;
    }

    /**
     * Sets the value of the woschedulecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWOSCHEDULECODE(String value) {
        this.woschedulecode = value;
    }

}
